@@ -71,14 +71,15 @@ func (f *httpMultiFlagList) Set(value string) error {
 
 // Usage to a writer.
 func usage(w io.Writer, msgs ...interface{}) {
-	_, _ = fmt.Fprintf(w, "Φορτίο %s usage:\n\t%s command [flags] target\n%s\n%s\n%s\n%s\n%s\n%s\n",
+	_, _ = fmt.Fprintf(w, "Φορτίο %s usage:\n\t%s command [flags] target\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n",
 		version.Short(),
 		os.Args[0],
 		"where command is one of: load (load testing), server (starts ui, http-echo,",
-		"redirect, proxies, tcp-echo and grpc ping servers), tcp-echo (only the tcp-echo",
-		"server), report (report only UI server), redirect (only the redirect server),",
-		"proxies (only the -M and -P configured proxies), grpcping (grpc client),",
-		"or curl (single URL debug), or nc (single tcp or udp:// connection).",
+		" redirect, proxies, tcp-echo and grpc ping servers), tcp-echo (only the tcp-echo",
+		" server), report (report only UI server), redirect (only the redirect server),",
+		" proxies (only the -M and -P configured proxies), grpcping (grpc client),",
+		" or curl (single URL debug), or nc (single tcp or udp:// connection),",
+		" or version (prints the version).",
 		"where target is a url (http load tests) or host:port (grpc health test).")
 	bincommon.FlagsUsage(w, msgs...)
 }
